@@ -36,9 +36,9 @@ dt_call.dtplyr_step_set <- function(x, needs_copy = x$needs_copy) {
 
 #' Set operations
 #'
-#' These are methods for the dplyr generics [intersect()], [union()],
-#' [union_all()], and [setdiff()]. They are translated to
-#' [data.table::fintersect()], [data.table::funion()], and
+#' These are methods for the dplyr generics [generics::intersect()], 
+#' [generics::union()], [union_all()], and [generics::setdiff()]. They are 
+#' translated to [data.table::fintersect()], [data.table::funion()], and
 #' [data.table::fsetdiff()].
 #'
 #' @importFrom dplyr intersect
@@ -60,12 +60,6 @@ intersect.dtplyr_step <- function(x, y, ...) {
   step_set(x, y, style = "intersect")
 }
 
-# Exported onload
-intersect.data.table <- function(x, y, ...) {
-  x <- lazy_dt(x)
-  intersect(x, y, ...)
-}
-
 #' @importFrom dplyr union
 #' @rdname intersect.dtplyr_step
 # Exported onload
@@ -76,12 +70,6 @@ union.dtplyr_step <- function(x, y, ...) {
   step_set(x, y, style = "union")
 }
 
-# Exported onload
-union.data.table <- function(x, y, ...) {
-  x <- lazy_dt(x)
-  union(x, y, ...)
-}
-
 #' @importFrom dplyr union_all
 #' @rdname intersect.dtplyr_step
 #' @export
@@ -92,12 +80,6 @@ union_all.dtplyr_step <- function(x, y, ...) {
   step_set(x, y, style = "union_all")
 }
 
-#' @export
-union_all.data.table <- function(x, y, ...) {
-  x <- lazy_dt(x)
-  union_all(x, y, ...)
-}
-
 #' @importFrom dplyr setdiff
 #' @rdname intersect.dtplyr_step
 # Exported onload
@@ -107,9 +89,3 @@ setdiff.dtplyr_step <- function(x, y, ...) {
   }
   step_set(x, y, style = "setdiff")
 }
-
-# Exported onload
-setdiff.data.table <- function(x, y, ...) {
-  x <- lazy_dt(x)
-  setdiff(x, y, ...)
-}
