@@ -24,7 +24,30 @@ arrange.dtplyr_step <- function(.data, ..., .by_group = FALSE) {
     return(.data)
   }
 
+  no_transmute <- all(map_lgl(dots, is_simple_arrange))
   # Order without grouping then restore
-  step <- step_subset(.data, i = call2("order", !!!dots), groups = character())
+  dots <- set_names(dots, NULL)
+  if (is_copied(.data) && no_transmute) {
+    dots <- c(dots, na.last = TRUE)
+    step <- step_call(.data, "setorder", dots)
+  } else {
+    step <- step_subset(.data, i = call2("order", !!!dots), groups = character())
+  }
   step_group(step, groups = .data$groups)
 }
+
+is_copied <- function(x) {
+  x$implicit_copy || x$needs_copy
+}
+
+is_simple_arrange <- function(x) {
+  out <- FALSE
+  if (is_symbol(x)) {
+    out <- TRUE
+  } else if (is_call(x, "-", 1)) {
+    if (is_symbol(x[[2]])) {
+      out <- TRUE
+    }
+  }
+  out
+}
